# Limits

If $f(x)$ is defined for all $x$ near a, except possibly at a itself, and if it can be ensured that $f(x)$ is as close to $L$ by taking $x$ close enough to $a$, but not equal to $a$. Then $f$ approaches the **limit** $L$ as $x$ approaches $a$:

$$
\lim_{x \to a} f(x) = L
$$

## One-sided limits

If $f(x)$ is defined on some interval $(b,a)$ extending to the left of $x=a$, and if it can be ensured that $f(x)$ is as close to $L$ by taking $x$ to the left of $a$ and close enough to $a$, then $f(x) has **left limit** $L$ at $x=a$ and:

$$
\lim_{x \uparrow a} f(x) = L.
$$

If $f(x)$ is defined on some interval $(b,a)$ extending to the right of $x=a$ and if it can be ensured that $f(x)$ is as close to $L$ by taking $x$ to the right of $a$ and close enough to $a$, then $f(x) has **right limit** $L$ at $x=a$ and:

$$
\lim_{x \downarrow a} f(x) = L.
$$

## Limits at infinity

If $f(x)$ is defined on an interval $(a,\infty)$ and if it can be ensured that $f(x)$ is as close to $L$ by taking $x$ large enough, then $f(x)$ **approaches the limit $L$ as $x$ approaches infinity** and 

$$
\lim_{x \to \infty} f(x) = L
$$

## Limit rules

If $\lim_{x \to a} f(x) = L$, $\lim_{x \to a} g(x) = M$, and $k$ is a constant then,

* **Limit of a sum:** $\lim_{x \to a}[f(x) + g(x)] = L + M$.
* **Limit of a difference:** $\lim_{x \to a}[f(x) - g(x)] = L - M$.
* **Limit of a multiple:** $\lim_{x \to a}k f(x) = k L$.
* **Limit of a product:** $\lim_{x \to a}f(x) g(x) = L M$.
* **Limit of a quotient:** $\lim_{x \to a}\frac{f(x)}{g(x)} = \frac{L}{M}$,  if $M \neq 0$.
* **Limit of a power:** $\lim_{x \to a}[f(x)]^\frac{m}{n} = L^{\frac{m}{n}}$.

## Formal definition of a limit

The limit $\lim_{x \to a} f(x) = L$ means,

$$
\forall \varepsilon_{> 0} \exists \delta_{>0} \Big[ 0<|x-a|<\delta \implies |f(x) - L| < \varepsilon \Big].
$$

The limit $\lim_{x \to \infty} f(x) = L$ means,

$$
\forall \varepsilon_{> 0} \exists N_{>0} \Big[x > N \implies |f(x) - L | < \varepsilon \Big].
$$

The limit $\lim_{x \to a} f(x) = \infty$ means,

$$
\forall M_{> 0} \exists \delta_{>0} \Big[ 0<|x-a|<\delta \implies f(x) > M \Big].
$$

The limit $\lim_{x \to \infty} f(x) = \infty$ means,

$$
\forall M_{> 0} \exists N_{>0} \Big[ x > N \implies f(x) > M \Big].
$$

For one-sided limits there are similar formal definitions.

### Example

Applying the formal definition of a limit for $\lim_{x \to 4}\sqrt{2x + 1}$

* Given $\varepsilon > 0$
* Choose $\delta = \frac{\varepsilon}{2}$
* Suppose $0 < |x - 4| < \delta$
* Check $|\sqrt{2x + 1} - 3|$

$$
\begin{array}{ll}
|\sqrt{2x + 1} - 3| &= |\frac{(\sqrt{2x + 1} - 3)(\sqrt{2x + 1} + 3)}{\sqrt{2x + 1} + 3}|\\
                    &= \frac{2|x - 4|}{\sqrt{2x + 1} + 3}\\
                    &< 2|x-4|\\
                    &< 2\delta = \varepsilon
\end{array}
$$

## Squeeze Theorem

Suppose that $f(x) \leq g(x) \leq h(x)$ holds for all $x$ in some open interval containing $a$, except possibly at $x=a$ itself. Suppose also that

$$\lim_{x \to a} f(x) = \lim_{x \to a} h(x) = L.$$

Then $\lim_{x \to a} g(x) = L$ also. Similar statements hold for left and right limits.

### Example

Applying squeeze theorem on $\lim_{x \to 0} x^2 \cos(\frac{1}{x})$.

$$
\begin{array}{ll}
\forall x \neq 0\\
-1 \leq \cos(\frac{1}{x}) \leq 1 \implies -x^2 \leq x^2 \cos(\frac{1}{x}) \leq x^2\\
\mathrm{Since,} \space \lim_{x \to 0} x^2 = \lim_{x \to 0} -x^2 = 0\\
\lim_{x \to 0} x^2 \cos(\frac{1}{x}) = 0
\end{array}
$$