# Complex numbers

## Definition

Let $p: A \to B$ be a quadratic equation given by

$$
    p(x) = ax^2 + bx + c, \qquad x \in A.
$$

If we have $A,B \subseteq \mathbb{R}$ we can describe the descriminant $D$ of $p$ as

$$
    D = b^2 - 4ac \begin{cases}>0: \text{two real solutions},\\ =0: \text{one real solution},\\ <0: \text{no real solution}.\end{cases}
$$

We may now define a set of numbers such that the discriminant $D$ of $p$ can be expressed as

$$
    D = b^2 - 4ac \begin{cases}>0: \text{two solutions},\\ =0: \text{one solution},\\ <0: \text{two  solutions},\end{cases}
$$

with $A,B \subseteq \mathbb{C}$. We call these the complex numbers.

> *Definition*: let $z=a+bi$ with $a,b \in \mathbb{R}$ and $i^2 = -1$ is the definition of a complex number. The set of complex numbers is denoted by $\mathbb{C}$. Such that we have $z \in \mathbb{C}$.
>
> * The real part of the complex number $z$ is given by $\mathrm{Re}(z) = a$.
> * The imaginary part of the complex number $z$ is given by $\mathrm{Im}(z) = b$.
> * The modulus of the complex number $z$ is given by $|z| = \sqrt{a^2+b^2}$.
> * The conjugate of the complex number $z$ is given by $\overline z = a - bi$.

## Properties of the complex numbers

> *Proposition*: let $z = a + bi$ be a complex number. The product of $z$ with its conjugate $\overline z$ is given by $z \overline z = |z|^2$. 

??? note "*Proof*:"

    Suppose $z = a + bi$ is complex number then $\overline z = a - bi$ is its conjugate and we have

    $$
        z \overline z = (a+bi)(a-bi) = a^2 - b^2 i^2 = a^2 + b^2 = |z|^2.
    $$

> *Proposition*: let $z_\alpha = a_\alpha + b_\alpha i$ with $\alpha \in \{1,2\}$ be two complex numbers.
>
> * Addition of two complex numbers is given by $z_1 + z_2 = (a_1 + a_2) + (b_1 + b_2)i$.
> * Multiplication of two complex numbers is given by $z_1 z_2 = (a_1 a_2 - b_1 b_2) + (a_1 b_2 + a_2 b_1)i$. 
> * Division of two complex numbers is given by $\frac{z_1}{z_2} = \frac{a_1 a_2 + b_1 b_2}{a_2^2 + b_2^2} + \frac{-a_1 b_2 + a_2 b_1}{a_2^2 + b_2^2}i = \frac{z_1 \overline z_2}{|z_2|^2}$.

??? note "*Proof*:"

    Suppose $z_\alpha = a_\alpha + b_\alpha i$ with $\alpha \in \{1,2\}$ are two complex numbers.

    For addition we have

    $$
        z_1 + z_2 = (a_1 + b_1 i) + (a_2 + b_2 i) = (a_1 + a_2) + (b_1 + b_2)i.
    $$

    For multiplication we have

    $$
        z_1 z_2 = (a_1 + b_1 i)(a_2 + b_2 i) = (a_1 a_2 + b_1 b_2 i^2) + (b_1 a_2 + a_1 b_2) i = (a_1 a_2 - b_1 b_2) + (a_1 b_2 + a_2 b_1)i.
    $$

    For division we have

    $$
        \frac{z_1}{z_2} = \frac{z_1 \overline z_2}{z_2 \overline z_2} = \frac{z_1 \overline z_2}{|z_2|^2} = \frac{(a_1 + b_1 i)(a_2 - b_2 i)}{|z_2|^2} = \frac{a_1 a-2 - b_1 b_2 i^2 + (b_1 a_2 - b_2 a_1)i}{|z_2|^2} = \frac{a_1 a_2 + b_1 b_2}{a_2^2 + b_2^2} + \frac{-a_1 b_2 + a_2 b_1}{a_2^2 + b_2^2}i,
    $$

    is thus also a complex number.

For real numbers the calculation rules are in agreement with the ordinary calculation rules for addition, multiplication and division of real numbers. Consequenty, the complex number system is an extension of the real number system. 

## Geometry of complex numbers

Complex numbers may be represented as vectors in the complex plane, spanned by the real and imaginary axes. The addition of the complex numbers may then be observed as vector addition. 

> *Definition*: let $z \in \mathbb{C}$ be a complex number and $C$ a circle with radius $r \in \mathbb{R}^+$ and center $c \in \mathbb{C}$. Then the circle $C$ is given by
>
> $$
>   |z - c| = r.
> $$
>
> The unit circle is given by $|z| = 1 = z \overline z$.

Each point on the unit circle has rectangular coordinates of the form $(\cos \varphi, \sin \varphi)$, with $\varphi$ the angle with respect to the postitive real number axis.

> *Proposition*: let $z \in \mathbb{C}$ be a complex number given by
>
> $$
>   z = \cos \varphi + i \sin \varphi,
> $$
>
> with $\varphi \in [0, 2\pi)$ describes a point on the unit circle.

??? note "*Proof*:"

    let $z \in \mathbb{C}$ be a complex number given by $z = \cos \varphi + i \sin \varphi$ with $\varphi \in [0, 2\pi)$. We have

    $$
        |z|= |\cos \varphi + i \sin \varphi| = \sqrt{\cos^2 \varphi + \sin^2 \varphi} = \sqrt{1} = 1.
    $$

The angle $\varphi$ is called the argument of its corresponding complex number $z$, denoted by $\varphi = \mathrm{arg}(z)$. 

> *Proposition*: let $z_\alpha = \cos \varphi_\alpha + i \sin \varphi_\alpha$ with $\varphi_\alpha \in \mathbb{R}$ and $\alpha \in \{1,2\}$ be two complex numbers on the unit circle. 
>
> * Multiplication of two complex numbers on the unity circle gives $z_1 z_2 = \cos (\varphi_1 + \varphi_2) + i \sin (\varphi_1 + \varphi_2)$. 
> * Division of two complex numbers on the unity circle gives $\frac{z_1}{z_2} = \cos (\varphi_1 - \varphi_2) + i \sin (\varphi_1 - \varphi_2).$

??? note "*Proof*:"

    let $z_\alpha = \cos \varphi_\alpha + i \sin \varphi_\alpha$ with $\varphi_\alpha \in \mathbb{R}$ and $\alpha \in \{1,2\}$ be two complex numbers on the unit circle. 

    We have for multiplication

    $$
    \begin{align*}
        z_1 z_2 &= (\cos \varphi_1 + i \sin \varphi_1)(\cos \varphi_2 + i \sin \varphi_2), \\
                &= (\cos \varphi_1 \cos \varphi_2 - \sin \varphi_1 \sin \varphi_2) + i (\cos \varphi_1 \sin \varphi_2 + \sin \varphi_1 \cos \varphi_2), \\
                &= \cos (\varphi_1 + \varphi_2) + i \sin (\varphi_1 + \varphi_2).
    \end{align*}
    $$

    We have then for division

    $$
    \begin{align*}
        \frac{z_1}{z_2} &= \frac{z_1 \overline z_2}{|z_2|^2}, \\ 
                        &= \frac{(\cos \varphi_1 + i \sin \varphi_1)(\cos \varphi_2 - i \sin \varphi_2)}{1}, \\
                        &= (\cos \varphi_1 \cos \varphi_2 + \sin \varphi_1 \sin \varphi_2) + i (\sin \varphi_1 \cos \varphi_2 - \cos \varphi_1 \sin \varphi_2), \\
                        &= \cos (\varphi_1 - \varphi_2) + i \sin (\varphi_1 - \varphi_2).
    \end{align*}
    $$

In argument notation we then have

* For multiplication: $\mathrm{arg}(z_1 z_2) = \mathrm{arg}(z_1) + \mathrm{arg}(z_2)$.
* For division: $\mathrm{arg}(\frac{z_1}{z_2}) = \mathrm{arg}(z_1) - \mathrm{arg}(z_2)$.

## Euler's formula

> *Theorem*: a point on the unit circle can also be described by
>
> $$
>   e^{i \varphi} = \cos \varphi + i \sin \varphi,
> $$
>
> with $\varphi \in \mathbb{R}$.

??? note "*Proof*:"

    Using the power-series of $e^x$ given by

    $$
        e^x = 1 + x + \frac{x^2}{2!} + \frac{x^3}{3!} + \frac{x^4}{4!} + \frac{x^5}{5!} + \frac{x^6}{6!} + \frac{x^7}{7!} + \dots.
    $$

    Let $x = i \varphi$ obtains

    $$
    \begin{align*}
        e^{i \varphi} &= 1 + i \varphi + \frac{(i \varphi)^2}{2!} + \frac{(i \varphi)^3}{3!} + \frac{(i \varphi)^4}{4!} + \frac{(i \varphi)^5}{5!} + \frac{(i \varphi)^6}{6!} + \frac{(i \varphi)^7}{7!} + \dots, \\
        &= 1 + i \varphi - \frac{\varphi^2}{2!} - \frac{i \varphi^3}{3!} + \frac{\varphi^4}{4!} + \frac{i \varphi^5}{5!} - \frac{\varphi^6}{6!} - \frac{i \varphi^7}{7!} + \dots, \\
        &= \Big(1 - \frac{\varphi^2}{2!} + \frac{\varphi^4}{4!} - \frac{\varphi^6}{6!} + \dots \Big) + i \Big(\varphi - \frac{\varphi^3}{3!} + \frac{\varphi^5}{5!} - \frac{\varphi^7}{7!} + \dots\Big), \\
        &= \cos \varphi + i \sin \varphi,
    \end{align*}
    $$

    where in the last step the two terms are recognized as the Maclaurin series for $\cos \varphi$ and $\sin \varphi$. The rearrangement of terms is justified beceause each series is absolutely convergent.

We may obtain Euler's identity given by $e^{i \pi} + 1 = 0$ from this theorem, by taking $\varphi = \pi$. 

> *Theorem*: for any $\varphi \in \mathbb{R}$ and $n \in \mathbb{N}$ it holds that
>
> $$
>   (\cos \varphi + i \sin \varphi)^n = \cos n \varphi + i \sin n \varphi,
> $$
>
> known as de Moivre's theorem. 

??? note "*Proof*:"

    Let $\varphi \in \mathbb{R}$ and $n \in \mathbb{N}$, the proof follows from Euler's formula by taking

    $$
        (\cos \varphi + i \sin \varphi)^n = (e^{i \varphi})^n = e^{i \varphi n} = \cos n \varphi + i \sin n \varphi.
    $$

With de Moivre's theorem the trigonometric identies can be derived. For example by taking $n=2$ let $z$ be a complex number given by

$$
    z = (\cos \varphi + i \sin \varphi)^2 = \cos^2 \varphi - \sin^2 \varphi + 2i \cos \varphi \sin \varphi = \cos 2 \varphi + i \sin 2 \varphi,
$$

then $\mathrm{Re}(z) = \cos^2 \varphi - \sin^2 \varphi = \cos 2 \varphi$ and $\mathrm{Im}(z) = 2 \cos \varphi \sin \varphi = \sin 2 \varphi$. 

## Roots of polynomials

> *Definition*: let $p$ be a complex polynomial of degree $n$ given by 
>
> $$
>   p(z) = \alpha_0 + \alpha_1 z + \alpha_2 z^2 + \dots + \alpha_n z^n,
> $$
>
> with $\alpha_i, z \in \mathbb{C}$ for $i \in \mathbb{N}$.

If for a certain $z_0 \in \mathbb{C}$ we have $p(z_0) = 0$ then $z_0$ is called a *zero* of the polynomial.

> *Lemma*: if $z_0 \in \mathbb{C}$ is a zero of $p$ then there exists a complex polynomial $q$ such that $p(z) = (z-z_0)q(z)$ for all $z \in \mathbb{C}$. 

??? note "*Proof*:"

    Will be added later.

> *Theorem* **- Fundamental theorem of algebra**: for each $n^\text{th}$-degree complex polynomial $p$ with $n \in \mathbb{N}$ there are $n$ complex numbers $z_1, \dots, z_n$ such that $p(z) = \gamma (z - z_0)(z - z_1) \cdots (z - z_n)$ for all $z \in \mathbb{C}$. 

??? note "*Proof*:"

    Will be added later.
 
> *Theorem*: each real polynomial can be written as a product of real linear factors and real quadratic factors with a negative discriminent.

??? note "*Proof*:"

    Will be added later.

From this theorem it follows that for a certain zero $z \in \mathbb{C}$ of a real polynomial $p$ its conjugate $\overline z$ is also a zero for the real polynomial $p$. Since $a = \overline a$ for $a \in \mathbb{R}$. 