# Interference

> *Definition*: when waves are combined in phase they combine to give a larger amplitude constructive interference occurs. When waves are combined out of phase they tend to cancel, destructive interference occurs.

## Two source interference

For interference between two monochromatic electromagnetic waves given by

$$
\begin{align*}
    \mathbf{E}_1(\mathbf{v}, t) = \mathbf{E}_{01} \exp i \big(\langle \mathbf{k_1}, \mathbf{v} - \mathbf{s}_1 \rangle - \omega_1 t + \varphi_1 \big), \\
    \\
    \mathbf{E}_2(\mathbf{v}, t) = \mathbf{E}_{02} \exp i \big(\langle \mathbf{k_2}, \mathbf{v} - \mathbf{s}_2 \rangle - \omega_2 t + \varphi_2 \big), \\
\end{align*}
$$

for all $(\mathbf{v}, t) \in U$ with $\mathbf{k}_{1,2} \in \mathbb{R}^3$ the wavenumber, $\mathbf{s}_{1,2} \in \mathbb{R}^3$ the position of the sources. Then we have the combined disturbance at  $\mathbf{v}$ is given by

$$
\begin{align*}
    \mathbf{E}(\mathbf{v}, t) &= \mathbf{E}_1(\mathbf{v}, t) + \mathbf{E}_2(\mathbf{v}, t), \\
                              &= \mathbf{E}_{01} \exp i \delta_1(\mathbf{v},t) + \mathbf{E}_{02} \exp i \delta_2(\mathbf{v},t),
\end{align*}
$$

for all $(\mathbf{v}, t) \in U$ with $\delta_i$ the phase difference for $i \in \{1,2\}$ given by

$$
    \delta_i(\mathbf{v}, t) = \langle \mathbf{k_i}, \mathbf{v} - \mathbf{s}_i \rangle - \omega_i t + \varphi_i.
$$

> *Law*: the irradiance at point $\mathbf{v}$ is then given by
>
> $$
>   I(\mathbf{v}, t) = I_1 + I_2 + 2\sqrt{I_1 I_2} \cos \Big(\delta_2(\mathbf{v}, t) - \delta_1(\mathbf{v}, t) \Big),
> $$
>
> for all $(\mathbf{v}, t) \in U$ with $I_{1,2} \in \mathbb{R}$ the irradiance for each wave seperately.

??? note "*Proof*:"

    Will be added later.

Let $\delta(\mathbf{v}, t) = \delta_2(\mathbf{v}, t) - \delta_1(\mathbf{v}, t)$, then we have for $\delta(\mathbf{v}, t) = 2 m \pi$ with $m \in \mathbb{Z}$ constructive interference and for $\delta(\mathbf{v}, t) = (2m + 1) \pi$ we have destructive interference. 

Writing out $\delta$ for plane waves of the same angular frequency $\omega = \omega_1 = \omega_2$ and propation in the $x$-direction gives 

$$
    \delta(x, t) = k(x_2 - x_1) + (\varphi_2 - \varphi_1) = \frac{2\pi}{\lambda_0} n (x_2 - x_1) + (\varphi_2 - \varphi_1),
$$

for all $(x,t) \in \mathbb{R}^2$ and $n \in \mathbb{R}$ the index of refraction of the medium. The optical path difference is defined as $n (x_2 - x_1)$. 

### Double slit interference

Interference is created by plane waves illuminating both slits creating disturbances at both slits that are correlated in time. Assuming the slits are points sources and the waves have the same frequency, we have a superposition point $P$ described vertically with $y \in \mathbb{R}$ and $r_{1,2} \in \mathbb{R}$ the traveling distances from the slits to this point. Obtaining a phase difference

$$
    \delta = k(r_2 - r_1) + (\varphi_2 - \varphi_1),
$$

??? note "*Proof*:"

    Will be added later.

<br>

If we have $L \in \mathbb{R}$ the horizontal length between the slits and the point $P$ and $d \in \mathbb{R}$ the distance between the slits and assume $L >> d$ and $\varphi_2 - \varphi_1 = 0$ then

$$
    \delta(\theta) = kd \sin \theta,
$$

for all $\theta \in [-\frac{\pi}{2}, \frac{\pi}{2}]$ with $\tan \theta = \frac{y}{L}$.

??? note "*Proof*:"

    Will be added later.

## Thin film interference

Interference is created by plane waves illuminating a thin film of thickness $l \in \mathbb{R}$ and index of refraction $n_l \in \mathbb{R}$ under an angle of incidence $\theta \in [-\frac{\pi}{2}, \frac{\pi}{2}]$ deposited on a substrate with index of refraction $n_i \in \mathbb{R}$. A phase shift is introduced between the first external and internal reflected rays obtaining a phase difference $\delta$ given by

$$
    \delta(\theta) = k 2l \sqrt{n_l^2 - n_i^2 \sin^2 \theta},
$$

for all $\theta \in [-\frac{\pi}{2}, \frac{\pi}{2}]$ with $k \in \mathbb{R}$ the wavenumber. 

??? note "*Proof*:"

    Will be added later.

## Michelson interferometer

Interference created by splitting and recombining plane waves that have a difference in optical path. With a setup of two mirrors displaced with lengths $L_1, L_2 \in \mathbb{R}$ from the beam splitter under an angle $\theta$ with respect to the incoming plane wave. Assuming the setup is in *one* medium with index of refraction $n \in \mathbb{R}$. Obtaining a phase difference $\delta$ given by

$$
    \delta(\theta) = k 2n(L_2 - L_1) \cos \theta + \pi,
$$

for all $\delta \in [-\frac{\pi}{2}, \frac{\pi}{2}]$ with $k \in \mathbb{R}$ the wavenumber.

??? note "*Proof*:"

    Will be added later.

## Fabry-perot interferometer

Interference created by a difference in optical path length with a setup consisting of two parallel flat reflective surfaces seperated by a distance $d \in \mathbb{R}$ If both surfaces have reflection and transmission amplitude ratios $r,t \in [0,1]$ then the phase difference $\delta$ between two adjecent transmitted rays under an angle $\theta \in [-\frac{\pi}{2}, \frac{\pi}{2}]$ is given by

$$
    \delta(\theta) = 2 kd \cos \theta + 2 \varphi,
$$

for all $\theta \in [-\frac{\pi}{2}, \frac{\pi}{2}]$ with $\varphi \in [0. 2\pi)$ the phase change due to reflection dependent on the amplitude ratios.  

??? note "*Proof*:"

    Will be added later.

<br>

> *Definition*: The finesse $\mathcal{F}$ and the coefficient of finesse $F$ of a Fabry Perot interferometer are defined by
>
> $$
>   F = \frac{4R}{(1-R)^2} \quad\text{ and }\quad \mathcal{F} = \frac{\pi \sqrt{F}}{2} = \frac{\pi \sqrt{R}}{1 - R},
> $$
>
> with $R \in [0,1]$ the reflectance. The finesse can be seen as the measure of sharpness of the interference pattern.

<br>

> *Proposition*: the transmitted irradiance $I$ of a Fabry Perot interferometer is given by
>
> $$
>   I(\theta) = \frac{I_0}{1 + 4 (\mathcal{F} / \pi)^2  \sin^2 (\delta(\theta) / 2)}
> $$
>
> for all $\theta \in [-\frac{\pi}{2}, \frac{\pi}{2}]$ with $I_0 \in \mathbb{R}$.  

??? note "*Proof*:"

    Will be added later.

### The chromatic resolving power and free spectral range

The chromatic resolving power and free spectral range are measures that define the ability to distinguish certain features in interference or diffraction patterns. 

> *Definition*: The full width at half maximum $\text{FWHM}$ for the interference pattern of the Fabry Perot interferometer is defined to be 
>
> $$
>   \text{FWHM} = \frac{4}{\sqrt{F}},
> $$
>
> with $F \in \mathbb{R}$.

<br>

> *Definition*: the chromatic resolving power $\mathcal{R}$ is defined by
>
> $$
>   \mathcal{R} = \frac{\lambda}{\Delta \lambda},
> $$
>
> with $\lambda \in \mathbb{R}$ the base wavelength of the light and $\Delta \lambda \in \mathbb{R}$ the spectral resolution at the wavelength $\lambda$. 

<br>

> *Proposition*: the chromatic resolving power $\mathcal{R}$ of a Fabry Perot interferometer based on the $\text{FWHM}$ can be determined by
>
> $$
>   \mathcal{R} = \mathcal{F} m,
> $$
>
> with $m \in \mathbb{Z}$ the order of the principal maxima and $\mathcal{F} \in \mathbb{R}$ the finesse. 

??? note "*Proof*:"

    Will be added later.

<br>

> *Definition*: the free spectral range $\text{FSR}$ is the largest wavelength range for a given order that does not overlap the same range in an adjacent order.

<br>

> *Proposition*: the free spectral range $\text{FSR}$ of a Fabry Perot interferometer can be determined by
>
> $$
>   \text{FSR} = \frac{\lambda}{m},
> $$
>
> with $m \in \mathbb{Z}$ the order and $\lambda \in \mathbb{R}$ the wavelength. 

??? note "*Proof*:"

    Will be added later.
