# Systems

> *Definition*: a system transforms signals.

## Operators

> *Definition*: let $x,y: \mathbb{R} \to \mathbb{R}$ be the input and output signal related to an operator $T$ by
>
> $$
>   y(t) = T[x(t)]
> $$
>
> for all $t \in \mathbb{R}$. 

For example for a time shift of the signal $S_{t_0}: y(t) = x(t - t_0)$ we have $y(t) = S_{t_0}[x(t)]$ for all $t \in \mathbb{R}$. For an amplifier of the signal $P: y(t) = k(t) x(t)$ we have $y(t) = P[x(t)]$ for all $t \in \mathbb{R}$.

> *Definition*: for systems $T_i$ for $i \in \{1, \dots, n\}$ with $n \in \mathbb{N}$ in parallel we define operator addition by
>
> $$
>   T = T_1 + \dots + T_n,
> $$
>
> such that for $x,y: \mathbb{R} \to \mathbb{R}$ the input and output signal obtains
>
> $$
>   y(t) = T[x(t)] = (T_1 + \dots + T_n)[x(t)] = T_1[x(t)] + \dots + T_n[x(t)],
> $$
>
> for all $t \in \mathbb{R}$. 

<br>

> *Definition*: for systems $T_i$ for $i \in \{1, \dots, n\}$ with $n \in \mathbb{N}$ in series we define operator multiplication by
>
> $$
>   T = T_n \cdots T_1,
> $$
>
> such that for $x,y: \mathbb{R} \to \mathbb{R}$ the input and output signal obtains
>
> $$
>   y(t) = T[x(t)] =T_n \cdots T_1 [x(t)] = T_n[T_{n-1}\cdots T_1[x(t)]],
> $$
>
> for all $t \in \mathbb{R}$.

It may be observed that the operator product is not commutative.

## Properties of systems.

> *Definition*: a system $T$ with inputs $x_{1,2}: \mathbb{R} \to \mathbb{R}$ is linear if and only if
>
> $$
>   T[a x_1(t) + b x_2(t)] = a T_1[x_1(t)] + b T_2[x_2(t)]
> $$
>
> for all $t \in \mathbb{R}$ with $a,b \in \mathbb{C}$. 

<br>

> *Definition*: a system $T$ is time invariant if and only if for all $t \in \mathbb{R}$ a shift in the input $x: \mathbb{R} \to \mathbb{R}$ results only in a shift in the output $y: \mathbb{R} \to \mathbb{R}$
>
> $$
>   y(t) = T[x(t)] \iff y(t - t_0) = T[x(t - t_0)],
> $$
>
> for all $t_0 \in \mathbb{R}$. 

<br>

> *Definition*: a system $T$ is invertible if distinct input $x: \mathbb{R} \to \mathbb{R}$ results in distinct output $y: \mathbb{R} \to \mathbb{R}$; the system is injective. The inverse of $T$ is defined such that
>
> $$
>   T^{-1}[y(t)] = T^{-1}[T[x(t)]] = x(t)
> $$
>
> for all $t \in \mathbb{R}$. 

<br>

> *Definition*: a system $T$ is memoryless if the image of the output $y(t_0)$ with $y: \mathbb{R} \to \mathbb{R}$ depends only on the input $x(t_0)$ with $x: \mathbb{R} \to \mathbb{R}$ for all $t_0 \in \mathbb{R}$. 

<br>

> *Definition*: a system $T$ is causal if the image of the output $y(t_0)$ with $y: \mathbb{R} \to \mathbb{R}$ depends only on images of the input $x(t)$ for $t \leq t_0$ with $x: \mathbb{R} \to \mathbb{R}$ for all $t_0 \in \mathbb{R}$. 

It is commenly accepted that all physical systems are causal since by definition, a cause precedes its effect. But do not be fooled.

> *Definition*: a system $T$ is bounded-input $\implies$ bounded-output (BIBO) -stable if and only if for all $t \in \mathbb{R}$ the output $y: \mathbb{R} \to \mathbb{R}$ is bounded for bounded input $x: \mathbb{R} \to \mathbb{R}$. Then 
>
> $$
>   |x(t)| \leq M \implies |y(t)| \leq P,
> $$
>
> for all $M, P \in \mathbb{R}$. 

## Linear time invariant systems

Linear time invariant systems are described by linear operators whose action on a system does not expicitly depend on time; time invariance.

> *Definition*: consider a LTI-system $T$ given by
>
> $$
>   y(t) = T[x(t)],
> $$
>
> for all $t \in \mathbb{R}$. The impulse response $h: \mathbb{R} \to \mathbb{R}$ of this systems is defined as
>
> $$
>   h(t) = T[\delta(t)]
> $$
>
> for all $t \in \mathbb{R}$ with $\delta$ the Dirac delta function.

It may be literally interpreted as the effect of an impulse at $t = 0$ on the system.

> *Theorem*: for a LTI-system $T$ with $x,y,h: \mathbb{R} \to \mathbb{R}$ the input, output and impulse response of the system we have
>
> $$
>   y(t) = h(t) * x(t),
> $$
>
> for all $t \in \mathbb{R}$. 

??? note "*Proof*:"

    Will be added later.

Therefore the system $T$ is completely characterized by the impulse response of $T$.

> *Theorem*: for two LTI-systems in parallel given by $T = T_1 + T_2$ with $x,y,h_1,h_2: \mathbb{R} \to \mathbb{R}$ the input, output and impulse response of both systems we have
>
> $$
>   y(t) = (h_1(t) + h_2(t)) * x(t),
> $$
>
> for all $t \in \mathbb{R}$.

??? note "*Proof*:"

    Will be added later.

<br>

> *Theorem*: for two LTI-systems in series given by $T = T_2 T_1$ with $x,y,h_1,h_2: \mathbb{R} \to \mathbb{R}$ the input, output and impulse response of both systems we have
>
> $$
>   y(t) = (h_2(t) * h_1(t)) * x(t),
> $$
>
> for all $t \in \mathbb{R}$.

??? note "*Proof*:"

    Will be added later.

From the definition of convolutions we have $h_2 * h_1 = h_1 * h_2$ therefore the product of LTI-systems *is* commutative.

For a causal system there is no effect before its cause, a causal LTI system therefore must have an impulse response $h: \mathbb{R} \to \mathbb{R}$ that must be zero for all $t \in \mathbb{R}^-$. 

> *Theorem*: for a LTI-system and its impulse response $h: \mathbb{R} \to \mathbb{R}$ we have
>
> $$
>   h(t) \overset{\mathcal{F}}\longleftrightarrow H(\omega),
> $$
>
> for all $t, \omega \in \mathbb{R}$ with $H: \mathbb{R} \to \mathbb{C}$ the transfer function.

??? note "*Proof*:"

    Will be added later.

<br>

> *Theorem*: for a LTI system $T$ with $x,y,h: \mathbb{R} \to \mathbb{R}$ the input, output and its impulse if the inverse system $T^{-1}$ exists it has an impulse response $h^{-1}: \mathbb{R} \to \mathbb{R}$ such that
>
> $$
>   x(t) = h^{-1}(t) * y(t),
> $$
>
> for all $t \in \mathbb{R}$ if and only if
>
> $$
>   h^{-1} * h(t) = \delta(t),
> $$
>
> for all $t \in \mathbb{R}$. The transfer function of $T^{-1}$ is then given by
>
> $$
>   H^{-1}(\omega) = \frac{1}{H(\omega)},
> $$
>
> for all $\omega \in \mathbb{R}$.

??? note "*Proof*:"

    Will be added later.

<br>

Therefore a LTI-system is invertible if and only if $H(\omega) \neq 0$ for all $\omega \in \mathbb{R}$. 

> *Theorem*: the low pass filter $H: \mathbb{R} \to \mathbb{C}$  given by the transfer function
>
> $$
>   H(\omega) = \text{rect} \frac{\omega}{2\omega_b},
> $$
>
> for all $\omega \in \mathbb{R}$ with $\omega_b \in \mathbb{R}$ is not causal. Therefore assumed to be not physically realisable. 

??? note "*Proof*:"

    Will be added later.